@@ -55,10 +55,12 @@ Example set of cookies:
     13-Jun-1988 03:04:55 GMT; domain=.fidelity.com; path=/; secure
 ****/
 
+#include <stdlib.h>
 #include <string.h>
 #include <ctype.h>
 
 #include "cookie.h"
+#include "../include/setup.h"
 #include "getdate.h"
 
 /****************************************************************************
@@ -73,11 +75,13 @@ struct Cookie *cookie_add(struct CookieInfo *c,
                           char *lineptr) /* first non-space after the
                                             Set-Cookie: prefix */
 {
+  struct Cookie *clist;
   char what[MAX_COOKIE_LINE];
   char name[MAX_NAME];
   char *ptr;
   struct Cookie *co;
   time_t now = time(NULL);
+  bool replace_old = FALSE;
 
   /* First, alloc and init a new struct for it */
   co = (struct Cookie *)malloc(sizeof(struct Cookie));
@@ -87,26 +91,21 @@ struct Cookie *cookie_add(struct CookieInfo *c,
   /* clear the whole struct first */
   memset(co, 0, sizeof(struct Cookie));
 	    
-  /* first, point to our "next" */
-  co->next = c->cookies;
-  /* then make ourselves first in the list */
-  c->cookies = co;
-  
   ptr=strtok(lineptr, ";"); /* first tokenize it on the semicolon */
   while(ptr) {
     /* we have a <what>=<this> pair or a 'secure' word here */
     if(strchr(ptr, '=')) {
       if(2 == sscanf(ptr, "%" MAX_NAME_TXT "[^=]=%"
-                     MAX_COOKIE_LINE_TXT "[^\n]",
+                     MAX_COOKIE_LINE_TXT "[^\r\n]",
                      name, what)) {
         /* this is a legal <what>=<this> pair */
-        if(!strcasecmp("path", name)) {
+        if(strequal("path", name)) {
           co->path=strdup(what);
         }
-        else if(!strcasecmp("domain", name)) {
+        else if(strequal("domain", name)) {
           co->domain=strdup(what);
         }
-        else if(!strcasecmp("expires", name)) {
+        else if(strequal("expires", name)) {
           co->expirestr=strdup(what);
           co->expires = get_date(what, &now);
         }
@@ -123,9 +122,9 @@ struct Cookie *cookie_add(struct CookieInfo *c,
       }
     }
     else {
-      if(sscanf(ptr, "%" MAX_COOKIE_LINE_TXT "[^\n]",
+      if(sscanf(ptr, "%" MAX_COOKIE_LINE_TXT "[^\r\n]",
                 what)) {
-        if(!strcasecmp("secure", what))
+        if(strequal("secure", what))
           co->secure = TRUE;
         else
           ; /* unsupported keyword without assign! */
@@ -135,6 +134,69 @@ struct Cookie *cookie_add(struct CookieInfo *c,
     while(ptr && *ptr && isspace(*ptr))
       ptr++;
   }
+  /* now, we have parsed the incoming line, we must now check if this
+     superceeds an already existing cookie, which it may if the previous have
+     the same domain and path as this */
+
+  clist = c->cookies;
+  replace_old = FALSE;
+  while(clist) {
+    if(strequal(clist->name, co->name)) {
+      /* the names are identical */
+
+      if(clist->domain && co->domain) {
+        if(strequal(clist->domain, co->domain))
+          replace_old=TRUE;
+      }
+      else if(!clist->domain && !co->domain)
+        replace_old = TRUE;
+
+      if(replace_old) {
+        /* the domains were identical */
+
+        if(clist->path && co->path) {
+          if(strequal(clist->path, co->path)) {
+            replace_old = TRUE;
+          }
+          else
+            replace_old = FALSE;
+        }
+        else if(!clist->path && !co->path)
+          replace_old = TRUE;
+        else
+          replace_old = FALSE;
+        
+      }
+
+      if(replace_old) {
+        co->next = clist->next; /* get the next-pointer first */
+
+        /* then free all the old pointers */
+        if(clist->name)
+          free(clist->name);
+        if(clist->value)
+          free(clist->value);
+        if(clist->domain)
+          free(clist->domain);
+        if(clist->path)
+          free(clist->path);
+        if(clist->expirestr)
+          free(clist->expirestr);
+
+        *clist = *co;  /* then store all the new data */
+      }
+
+    }
+    clist = clist->next;
+  }
+
+  if(!replace_old) {
+
+    /* first, point to our "next" */
+    co->next = c->cookies;
+    /* then make ourselves first in the list */
+    c->cookies = co;
+  }
   return co;
 }
 
@@ -162,7 +224,7 @@ struct CookieInfo *cookie_init(char *file)
   fp = file?fopen(file, "r"):NULL;
   if(fp) {
     while(fgets(line, MAX_COOKIE_LINE, fp)) {
-      if(!strncasecmp("Set-Cookie:", line, 11)) {
+      if(strnequal("Set-Cookie:", line, 11)) {
         /* This is a cookie line, get it! */
         char *lineptr=&line[11];
         while(*lineptr && isspace(*lineptr))
@@ -215,17 +277,17 @@ struct Cookie *cookie_getlist(struct CookieInfo *c,
          (co->secure?secure:TRUE) ) {
 
 	 /* now check if the domain is correct */
-	 domlen=strlen(co->domain);
+	 domlen=co->domain?strlen(co->domain):0;
 	 if(!co->domain ||
 	    ((domlen<hostlen) &&
-	     !strcasecmp(host+(hostlen-domlen), co->domain)) ) {
+	     strequal(host+(hostlen-domlen), co->domain)) ) {
 	    /* the right part of the host matches the domain stuff in the
 	       cookie data */
 
 	    /* now check the left part of the path with the cookies path
 	       requirement */
 	    if(!co->path ||
-	       !strncasecmp(path, co->path, strlen(co->path))) {
+	       strnequal(path, co->path, strlen(co->path))) {
 
 	       /* and now, we know this is a match and we should create an
 		  entry for the return-linked-list */
