@@ -2,7 +2,11 @@
 #define __COOKIE_H
 
 #include <stdio.h>
+#ifdef WIN32
+#include <time.h>
+#else
 #include <sys/time.h>
+#endif
 
 #include "../include/curl.h"
 
