@@ -24,13 +24,13 @@
  *
  * ------------------------------------------------------------
  * Main author:
- * - Daniel Stenberg <Daniel.Stenberg@sth.frontec.se>
+ * - Daniel Stenberg <Daniel.Stenberg@haxx.nu>
  *
- * 	http://www.fts.frontec.se/~dast/curl/
+ * 	http://curl.haxx.nu
  *
  * $Source: /cvs/curl/curl/lib/hostip.c,v $
- * $Revision: 1.3 $
- * $Date: 1999/03/14 21:12:50 $
+ * $Revision: 1.7 $
+ * $Date: 1999/09/06 06:59:40 $
  * $Author: dast $
  * $State: Exp $
  * $Locker:  $
@@ -42,9 +42,12 @@
 
 #include "../include/setup.h"
 
-#if defined(WIN32) && !defined(__GNUC__)
+#if defined(WIN32) && !defined(__GNUC__) || defined(__MINGW32__)
 #include <winsock.h>
 #else
+#ifdef HAVE_SYS_TYPES_H
+#include <sys/types.h>
+#endif
 #ifdef HAVE_SYS_SOCKET_H
 #include <sys/socket.h>
 #endif
