@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- * $Id: mprintf.c,v 1.1.1.1 1999/03/11 22:23:34 dast Exp $
+ * $Id: mprintf.c,v 1.2 1999/05/22 12:57:27 dast Exp $
  *
  *************************************************************************
  *
@@ -83,7 +83,7 @@
  *
  ****************************************************************************/
 
-static const char rcsid[] = "@(#)$Id: mprintf.c,v 1.1.1.1 1999/03/11 22:23:34 dast Exp $";
+static const char rcsid[] = "@(#)$Id: mprintf.c,v 1.2 1999/05/22 12:57:27 dast Exp $";
 
 /*
  * To test:
@@ -1223,8 +1223,8 @@ int main()
 #endif
 
   mprintf("%3d %5d\n", 10, 1998);
-
-  ptr=maprintf("test this then baby %d %d %d loser baby get a hit in yer face now!", 1998, 1999, 2001);
+  
+  ptr=maprintf("test this then baby %s%s%s%s%s%s %d %d %d loser baby get a hit in yer face now!", "", "pretty long string pretty long string pretty long string pretty long string pretty long string", "/", "/", "/", "pretty long string", 1998, 1999, 2001);
 
   puts(ptr);
 
