@@ -26,13 +26,13 @@
  *
  * ------------------------------------------------------------
  * Main author:
- * - Daniel Stenberg <Daniel.Stenberg@sth.frontec.se>
+ * - Daniel Stenberg <Daniel.Stenberg@haxx.nu>
  *
- * 	http://www.fts.frontec.se/~dast/curl/
+ * 	http://curl.haxx.nu
  *
  * $Source: /cvs/curl/curl/lib/progress.h,v $
- * $Revision: 1.2 $
- * $Date: 1999/04/05 15:54:01 $
+ * $Revision: 1.5 $
+ * $Date: 1999/09/06 06:59:41 $
  * $Author: dast $
  * $State: Exp $
  * $Locker:  $
@@ -46,8 +46,13 @@ void ProgressInit(struct UrlData *data, int max);
 void ProgressShow(struct UrlData *data,
                   int point, struct timeval start, struct timeval now, bool force);
 void ProgressEnd(struct UrlData *data);
+void ProgressMode(int mode);
 
 /* Don't show progress for sizes smaller than: */
 #define LEAST_SIZE_PROGRESS BUFSIZE
 
-#endif
+/* we want more progress info modes... */
+#define URG_PROGRESS_MODE_STATS (0) /* default is the mode with value 0 */
+#define URG_PROGRESS_MODE_BAR   (1)
+
+#endif /* __PROGRESS_H */
