@@ -24,13 +24,13 @@
  *
  * ------------------------------------------------------------
  * Main author:
- * - Daniel Stenberg <Daniel.Stenberg@sth.frontec.se>
+ * - Daniel Stenberg <Daniel.Stenberg@haxx.nu>
  *
- * 	http://www.fts.frontec.se/~dast/curl/
+ * 	http://curl.haxx.nu
  *
  * $Source: /cvs/curl/curl/lib/sendf.c,v $
- * $Revision: 1.4 $
- * $Date: 1999/03/14 21:17:14 $
+ * $Revision: 1.7 $
+ * $Date: 1999/09/06 06:59:41 $
  * $Author: dast $
  * $State: Exp $
  * $Locker:  $
@@ -47,7 +47,7 @@
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
-#if defined(WIN32) && !defined(__GNUC__)
+#if defined(WIN32) && !defined(__GNUC__) || defined(__MINGW32__)
 #include <winsock.h>
 #endif
 
