@@ -24,13 +24,13 @@
  *
  * ------------------------------------------------------------
  * Main author:
- * - Daniel Stenberg <Daniel.Stenberg@sth.frontec.se>
+ * - Daniel Stenberg <Daniel.Stenberg@haxx.nu>
  *
- * 	http://www.fts.frontec.se/~dast/curl/
+ * 	http://curl.haxx.nu
  *
  * $Source: /cvs/curl/curl/lib/speedcheck.c,v $
- * $Revision: 1.3 $
- * $Date: 1999/04/05 15:50:32 $
+ * $Revision: 1.6 $
+ * $Date: 1999/09/06 06:59:41 $
  * $Author: dast $
  * $State: Exp $
  * $Locker:  $
@@ -39,6 +39,9 @@
  ****************************************************************************/
 
 #include <stdio.h>
+#if defined(__MINGW32__)
+#include <winsock.h>
+#endif
 
 #include "../include/curl.h"
 #include "urldata.h"
