@@ -20,6 +20,7 @@ push @out, "                             / __| | | | |_) | |    \n";
 push @out, "                            | (__| |_| |  _ <| |___ \n";
 push @out, "                             \\___|\\___/|_| \\_\\_____|\n";
 
+$head=0;
 loop:
 while (<STDIN>) {
     $line = $_;
@@ -30,19 +31,23 @@ while (<STDIN>) {
     # then this:
     $line =~ s/.//g;
 
-    if($line =~ /^Curl/) {
+    if($line =~ /^curl/i) {
 	# cut off the page headers
+        $head=1;
 	next loop;
     } 
 
-    if($line eq "\n") {
+    if($line =~ /^[ \t]*\n/) {
 	$wline++;
 	# we only make one empty line max
 	next loop;
     }
     if($wline) {
 	$wline = 0;
-	push @out, "\n";
+        if(!$head) {
+            push @out, "\n";
+        }
+        $head =0;
     }
     push @out, $line;
 }
@@ -76,6 +81,5 @@ for(@out) {
 
 }
 
-print " ) ; ";
-print "}"
+print " ) ;\n}\n"
     
